@@ -14,9 +14,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-module.c 6740 2006-12-15 14:01:58Z chpe $
+ *  $Id$
  */
 
 #include "config.h"
@@ -152,6 +152,9 @@ ephy_module_load (GTypeModule *gmodule)
 
 	if (module->type == 0)
 	{
+		g_warning ("Failed to register the GType(s)!");
+		g_module_close (module->library);
+
 		return FALSE;
 	}
 
