@@ -25,10 +25,7 @@
 
 #include "ephy-node.h"
 
-#include <gtk/gtkwidget.h>
-#include <gtk/gtktoolitem.h>
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtkentrycompletion.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
@@ -73,17 +70,18 @@ void		ephy_location_entry_set_completion	(EphyLocationEntry *le,
 							 guint action_col,
 							 guint keywords_col,
 							 guint relevance_col,
+							 guint url_col,
 							 guint extra_col,
-							 guint favicon_col,
-							 guint url_col);
+							 guint favicon_col);
 
 void		ephy_location_entry_set_location	(EphyLocationEntry *le,
 							 const char *address,
 							 const char *typed_address);
 
-void		ephy_location_entry_set_completion_func (EphyLocationEntry *le, 
-							 GtkEntryCompletionMatchFunc completion_func,
-							 gpointer user_data);
+void		ephy_location_entry_set_match_func	(EphyLocationEntry *le, 
+							 GtkEntryCompletionMatchFunc match_func,
+							 gpointer user_data,
+							 GDestroyNotify notify);
 					
 const char     *ephy_location_entry_get_location	(EphyLocationEntry *le);
 
@@ -91,6 +89,8 @@ gboolean	ephy_location_entry_get_can_undo	(EphyLocationEntry *le);
 
 gboolean	ephy_location_entry_get_can_redo	(EphyLocationEntry *entry);
 
+GRegex *	ephy_location_entry_get_regex		(EphyLocationEntry *entry);
+
 gboolean	ephy_location_entry_reset		(EphyLocationEntry *entry);
 
 void		ephy_location_entry_undo_reset		(EphyLocationEntry *entry);
