@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-bookmark-action-group.h 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id$
  */
 
 #ifndef EPHY_BOOKMARK_ACTION_GROUP_H
@@ -24,7 +24,7 @@
 #include "ephy-link-action.h"
 #include "ephy-node.h"
 
-#include <gtk/gtkactiongroup.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
